@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.28.0";
+our $VERSION = "v0.28.4";
 
 1;
 __END__
@@ -49,8 +49,8 @@ RxPerl - an implementation of Reactive Extensions / rxjs for Perl
 You probably want to install one of the three adapter modules for your project instead of this one:
 L<RxPerl::AnyEvent>, L<RxPerl::IOAsync> or L<RxPerl::Mojo>.
 
-Each of these three modules adapt RxPerl to one of three event loops available in Perl (L<AnyEvent>,
-L<IO::Async> and L<Mojo::IOLoop>), so pick the one that corresponds to the event loop that your app uses.
+Each of these three modules adapt RxPerl to one of three event interfaces available in Perl (L<AnyEvent>,
+L<IO::Async> and L<Mojo::IOLoop>), so pick the one that corresponds to the event interface that your app uses.
 
 The documentation in this POD applies to all three adapter modules.
 
@@ -630,7 +630,7 @@ L<https://rxjs.dev/api/operators/withLatestFrom>
 
     # [0, 0], [1, 1], [2, 3], [3, 4], [4, 6], ...
     rx_interval(1)->pipe(
-        op_with_latest_from(rx_interval(1)),
+        op_with_latest_from(rx_interval(0.7)),
     )->subscribe($observer);
 
 =back
@@ -734,7 +734,7 @@ L<ReactiveX API|http://reactivex.io/documentation/operators.html> at a few point
 L<Rx* libraries|http://reactivex.io/languages.html>), RxPerl chose to behave like rxjs rather than
 ReactiveX to cater for web developers already familiar with rxjs.
 
-=head1 LEARNING MATERIAL
+=head1 LEARNING RESOURCES
 
 =over
 
